@@ -11,3 +11,7 @@ def check_dob_format(dob):
             "The date `{0}` does not match the format YYYY-MM-DD".format(dob),
         )
         raise
+
+
+def filter_del_lines_from_load_annotations(call):
+    return call.get("alt", "") != "<DEL>"
