@@ -6,13 +6,15 @@ from genomoncology.parse.ensures import ensure_collection
 from genomoncology.kms.annotations import AnnBundleVersionAssertionError
 
 
-def create_async_processor(state: "State", async_func, **kw):
+def create_async_processor(
+    state: "State", async_func, futures_batch_size=25, **kw
+):
     sdk = state.create_sdk(async_enabled=True)
 
     return [
         map(async_func(sdk=sdk, **kw)),
         # roll up the futures in batches, await, flatten
-        partition_all(state.batch_size),
+        partition_all(futures_batch_size),
         map(do_await(state)),
         concat,
     ]
