@@ -1,4 +1,5 @@
 from enum import Enum
+from cytoolz.curried import curry
 
 __TYPE__ = "__type__"
 __CHILD__ = "__child__"
@@ -9,6 +10,8 @@ class DocType(Enum):
     ANNOTATED_VARIANT = "ANNOTATED_VARIANT"
     ANNOTATED_TSV = "ANNOTATED_TSV"
     CALL = "CALL"
+    REF_CALL = "REF_CALL"
+    UNKNOWN_CALL = "UNKNOWN_CALL"
     SKIPPED_CALL = "SKIPPED_CALL"
     FEATURE = "FEATURE"
     GENE = "GENE"
@@ -35,6 +38,7 @@ class DocType(Enum):
     BAYLOR_WGL = "BAYLOR_WGL"
     DBNSFP = "DBNSFP"
     CLINVAR = "CLINVAR"
+    CLINVAR_XML = "CLINVAR_XML"
     THOUSANDGENOMES = "THOUSANDGENOMES"
     DBSNP = "DBSNP"
     EXAC = "EXAC"
@@ -48,10 +52,13 @@ class DocType(Enum):
     UNIPROT_DOMAIN = "UNIPROT_DOMAIN"
     UNIPROT = "UNIPROT"
     MITOMAP = "MITOMAP"
+    GENE_TYPE = "GENE_TYPE"
 
     def is_a(self, a_dict):
         try:
-            return a_dict[__TYPE__] == self.value
+            if isinstance(a_dict, dict):
+                return a_dict[__TYPE__] == self.value
+            return False
         except KeyError:
             return False
 
@@ -113,8 +120,17 @@ def is_not_skipped_call(doc):
     return DocType.SKIPPED_CALL.is_not(doc)
 
 
+@curry
+def filter_out_ref_unknown(doc, keep_ref_unknown_calls=False):
+    if not keep_ref_unknown_calls:
+        return DocType.REF_CALL.is_not(doc) and DocType.UNKNOWN_CALL.is_not(
+            doc
+        )
+    return True
+
+
 DEFAULT_COLUMNS = {
-    DocType.GENE.value: ["chromosome", "start", "end", "name"],
+    DocType.GENE.value: ["chromosome", "start", "end", "gene"],
     DocType.CALL.value: [
         "sample_name",
         "chr",
