@@ -9,6 +9,8 @@ from .functions import (
     is_multi_field,
     split_value,
     add_flag,
+    add_rollup,
+    get_boolean_value,
 )
 from .mapper_classes import VariantMapper
 
@@ -28,4 +30,6 @@ __all__ = (
     "is_multi_field",
     "split_value",
     "add_flag",
+    "add_rollup",
+    "get_boolean_value",
 )
