@@ -19,6 +19,7 @@ from . import (
     uniprot_domains,
     uniprot,
     mitomap,
+    gene_type,
 )
 
 __all__ = (
@@ -43,4 +44,5 @@ __all__ = (
     "uniprot_domains",
     "uniprot",
     "mitomap",
+    "gene_type",
 )
