@@ -10,6 +10,11 @@ NAME_MAPPING = {
     "hpo__mstring": "hpo_id",
 }
 
+
+def parse_hpo_gene(x):
+    return x["key"]
+
+
 register(
     input_type=DocType.AGGREGATE,
     output_type=DocType.HPO,
@@ -17,6 +22,7 @@ register(
         lambda x: assoc(x, "is_gene_annotation", True),
         lambda x: assoc(x, __TYPE__, DocType.HPO.value),
         name_mapping(NAME_MAPPING),
+        lambda x: assoc(x, "gene", parse_hpo_gene(x)),
     ),
 )
 
