@@ -5,7 +5,7 @@ from genomoncology.pipeline.transformers import register, name_mapping
 
 NAME_MAPPING = {
     "gene": "gene",
-    "gene_mim__string": "Mim Number",
+    "gene_mim__mstring": "Mim Number",
     "phenotype__mstring": "phenotype",
     "phenotype_mim__mstring": "phenotype_mim",
     "inheritance__mstring": "inheritance",
@@ -31,6 +31,14 @@ def parse_omim_inheritance(omim_pheno_d):
         "autosomal recessive",
         "Autosomal dominant",
         "Autosomal recessive",
+        "Mitochondrial",
+        "?Autosomal dominant",
+        "Isolated cases",
+        "Somatic mutation",
+        "Digenic recessive",
+        "Somatic mosaicism",
+        "?X - linked recessive",
+        "Inherited chromosomal imbalance",
     ]
     omim_pheno_d = assoc(
         omim_pheno_d,
@@ -95,6 +103,12 @@ def phenotype_pipeline(x):
 
 def parse_omim_phenotypes(x):
     if "Phenotypes" in x:
+
+        if all([phen == "None" for phen in x["Phenotypes"]]):
+            # do not add any of the phenotypes fields if they are all None
+            return x
+
+        x["Phenotypes"] = "; ".join(x["Phenotypes"])
         return merge_with(
             list, map(phenotype_pipeline, x["Phenotypes"].split("; "))
         )
@@ -103,13 +117,20 @@ def parse_omim_phenotypes(x):
 
 
 def parse_omim_gene(x):
-    return x["Gene Symbols"].split(", ")[0]
+    return x["key"]
+
+
+def replace_empty_or_null_strings_with_none(omim_ann):
+    for key in filter(lambda x: x.endswith("mstring"), omim_ann.keys()):
+        omim_ann[key] = ["None" if not v else v for v in omim_ann[key]]
+    return omim_ann
 
 
 register(
-    input_type=DocType.TSV,
+    input_type=DocType.AGGREGATE,
     output_type=DocType.OMIM,
     transformer=compose(
+        lambda x: replace_empty_or_null_strings_with_none(x),
         lambda x: assoc(x, "is_gene_annotation", True),
         lambda x: assoc(x, __TYPE__, DocType.OMIM.value),
         name_mapping(NAME_MAPPING),
@@ -120,7 +141,7 @@ register(
 )
 
 register(
-    input_type=DocType.TSV,
+    input_type=DocType.AGGREGATE,
     output_type=DocType.OMIM,
     transformer=compose(
         lambda x: assoc(x, "is_gene_annotation", True),
